==> homebridge-miot-1.4.4.tgz: package/lib/modules/airmonitor/AirMonitorDevice.js <==
const GenericDevice = require('../generic/GenericDevice.js');
const Constants = require('../../constants/Constants.js');
const DevTypes = require('../../constants/DevTypes.js');
const PropFormat = require('../../constants/PropFormat.js');
const PropUnit = require('../../constants/PropUnit.js');
const PropAccess = require('../../constants/PropAccess.js');


class AirMonitorDevice extends GenericDevice {
  constructor(device, name, logger) {
    super(device, name, logger);
  }


  /*----------========== LIFECYCLE ==========----------*/

  initialPropertyFetchDone() {
    super.initialPropertyFetchDone();
  }


  /*----------========== DEVICE INFO ==========----------*/

  getType() {
    return DevTypes.AIR_MONITOR;
  }

  getDeviceName() {
    return 'Unknown air monitor device';
  }


  /*----------========== CONFIG ==========----------*/

  propertiesToMonitor() {
    return ['environment:relative-humidity', 'environment:pm2.5-density', 'environment:pm10-density', 'environment:temperature',
    'environment:co2-density', 'environment:tvoc-density', 'battery:battery-level', 'battery:charging-state'
    ];
  }


  /*----------========== VALUES ==========----------*/


  /*----------========== PROPERTIES ==========----------*/

  //overrides

  //device specific


  /*----------========== ACTIONS ==========----------*/


  /*----------========== FEATURES ==========----------*/


  /*----------========== GETTERS ==========----------*/


  /*----------========== SETTERS ==========----------*/


  /*----------========== CONVENIENCE ==========----------*/


  /*----------========== VALUE CONVENIENCE  ==========----------*/


  /*----------========== HELPERS ==========----------*/


}

module.exports = AirMonitorDevice;

==> homebridge-miot-1.7.3.tgz: package/lib/modules/airmonitor/AirMonitorDevice.js <==
const BaseDevice = require('../../base/BaseDevice.js');
const Constants = require('../../constants/Constants.js');
const DevTypes = require('../../constants/DevTypes.js');
const PropFormat = require('../../constants/PropFormat.js');
const PropUnit = require('../../constants/PropUnit.js');
const PropAccess = require('../../constants/PropAccess.js');


class AirMonitorDevice extends BaseDevice {
  constructor(device, name, logger) {
    super(device, name, logger);
  }


  /*----------========== LIFECYCLE ==========----------*/

  initialPropertyFetchDone() {
    super.initialPropertyFetchDone();
  }


  /*----------========== DEVICE INFO ==========----------*/

  getType() {
    return DevTypes.AIR_MONITOR;
  }

  getDeviceName() {
    return 'Unknown air monitor device';
  }


  /*----------========== CONFIG ==========----------*/

  propertiesToMonitor() {
    return ['environment:relative-humidity', 'environment:pm2.5-density', 'environment:pm10-density', 'environment:temperature',
    'environment:co2-density', 'environment:tvoc-density', 'battery:battery-level', 'battery:charging-state'
    ];
  }


  /*----------========== VALUES ==========----------*/


  /*----------========== PROPERTIES ==========----------*/

  //overrides

  //device specific


  /*----------========== ACTIONS ==========----------*/


  /*----------========== FEATURES ==========----------*/


  /*----------========== GETTERS ==========----------*/


  /*----------========== SETTERS ==========----------*/


  /*----------========== CONVENIENCE ==========----------*/


  /*----------========== VALUE CONVENIENCE  ==========----------*/


  /*----------========== HELPERS ==========----------*/


}

module.exports = AirMonitorDevice;
